==> mdm-rpc-0.1.62-sources.jar: com/chinayanghe/msp/mdm/rpc/org/OrgMessageService.java <==
package com.chinayanghe.msp.mdm.rpc.org;



import java.util.List;
import java.util.Set;

import com.chinayanghe.msp.mdm.enums.OrgBlockType;
import com.chinayanghe.msp.mdm.enums.OrgType;
import com.chinayanghe.msp.mdm.vo.org.OrgBasicInformationVo;
import com.chinayanghe.msp.mdm.vo.org.OrgComplilationVo;

import cn.com.bizunited.cp.common.pagination.Page;
import cn.com.bizunited.cp.common.pagination.Pageable;

/**
 * Created by danDy on 2017/5/9.
 */
public interface OrgMessageService {
    /**
     * 根据组织编码获取组织下岗位编制信息
     * @param orgCode
     * @return
     */
    List<OrgComplilationVo> getOrgComlilationList(String orgCode);

    /**
     * 根据组织编码，数据权限，启用状态查询组织基本信息
     * @param orgCode
     * @param power "04"会查询所有下级组织，其他则没有，不能为null
     * @param enableStatus
     * @return
     */
    List<OrgBasicInformationVo>getOrgBasicInformationList(String orgCode,String power,Integer enableStatus);

    /**
     * 根据组织编码查询组织信息
     * @param orgCode
     * @return
     */
    OrgBasicInformationVo findByOrgCode(String orgCode);

    /**
     * 查找组织的组织树路径
     * @param orgCode 组织编码
     * @param positionCode 岗位编码 （优先组织编码）
     * @param orgTypes 截断组织类型（为null时查询为全路径）
     * @param orgBlockType 截断方式
     * @return
     */
    OrgBasicInformationVo findOrgPath(String orgCode, String positionCode,  OrgBlockType orgBlockType,OrgType... orgTypes );

    /**
     * 根据预算标识去查询组织信息
     * @param budgetFlag
     * @return
     * @deprecated 过时、情调分页接口 {@link OrgMessageService#findOrgPage(cn.com.bizunited.cp.common.pagination.Pageable)}
     */
    @Deprecated
    List<OrgBasicInformationVo>findByBudgetFlag(String budgetFlag);

    /**
     * 根据岗位编码、组织编码，查找指定层级的组织。
     * 如果当前岗位所在组织或组织层级在查找层级之上，则往下查找指定层级组织
     * 如果当前岗位所在组织或组织层级在查找层级之下，则往上查找指定层级组织
     * @param orgType 组织层级类型 必填
     * @param positionCode 岗位编码 可输
     * @param orgCode 组织编码 可输优先组织
     * @return
     */
    List<OrgBasicInformationVo> findOrgInfosByHierarchy(OrgType orgType, String positionCode, String orgCode);

    /**
     * 根据上级节点id查询同属这一组织的组织信息
     * @param parentId
     * @return
     */
    List<OrgBasicInformationVo> findByParentId(String parentId);

    /**
     * 查询组织code下的所有子组织编码（包含自己）
     * @param orgCode
     * @return
     */
    Set<String> findAllChildOrgsByCode(String orgCode);

    /**
     * 查询组织code下的所有子组织（包含自己）
     * @param orgCode
     * @return
     */
    List<OrgBasicInformationVo> findAllChildsByCode(String orgCode);

    /**
     * 分页查询组织信息
     * @param pageable cn.com.bizunited.cp.common.pagination.Pageable#queryCondition 说明-->orgName（ 组织名称 like）、orgCode （组织编码 eq）、orgNameOrCode  （组织编码或名称 like）、budgetFlag （预算标示 eq）、parentOrgCode(父组织编码，如果存在，只查询该组织下级组织)、
     *                 orgTypes(组织层级类型{@link com.chinayanghe.msp.mdm.enums.OrgType}集合or数组 eq)、orgTypeCodes(组织层级类型编码{@link com.chinayanghe.msp.mdm.enums.OrgType#orgHierarchyCode}集合or数组 eq)
     * @return
     */
    Page<OrgBasicInformationVo> findOrgPage(Pageable pageable);
    
    /**
     * 同步组织信息
     * @param vo
     */
    void synchronizOrgInfo(OrgBasicInformationVo vo);


    
}

==> mdm-rpc-0.1.92-sources.jar: com/chinayanghe/msp/mdm/rpc/org/OrgMessageService.java <==
package com.chinayanghe.msp.mdm.rpc.org;



import java.util.List;
import java.util.Set;

import com.chinayanghe.msp.mdm.enums.OrgBlockType;
import com.chinayanghe.msp.mdm.enums.OrgType;
import com.chinayanghe.msp.mdm.vo.org.OrgBasicInformationVo;
import com.chinayanghe.msp.mdm.vo.org.OrgComplilationVo;

import cn.com.bizunited.cp.common.pagination.Page;
import cn.com.bizunited.cp.common.pagination.Pageable;

/**
 * Created by danDy on 2017/5/9.
 */
public interface OrgMessageService {
    /**
     * 根据组织编码获取组织下岗位编制信息
     * @param orgCode
     * @return
     */
    List<OrgComplilationVo> getOrgComlilationList(String orgCode);

    /**
     * 根据组织编码，数据权限，启用状态查询组织基本信息
     * @param orgCode
     * @param power "04"会查询所有下级组织，其他则没有，不能为null
     * @param enableStatus
     * @return
     */
    List<OrgBasicInformationVo>getOrgBasicInformationList(String orgCode,String power,Integer enableStatus);

    /**
     * 根据组织编码查询组织信息
     * @param orgCode
     * @return
     */
    OrgBasicInformationVo findByOrgCode(String orgCode);

    /**
     * 查找组织的组织树路径
     * @param orgCode 组织编码
     * @param positionCode 岗位编码 （优先组织编码）
     * @param orgTypes 截断组织类型（为null时查询为全路径）
     * @param orgBlockType 截断方式
     * @return
     */
    OrgBasicInformationVo findOrgPath(String orgCode, String positionCode,  OrgBlockType orgBlockType,OrgType... orgTypes );

    /**
     * 根据预算标识去查询组织信息
     * @param budgetFlag
     * @return
     * @deprecated 过时、情调分页接口 {@link OrgMessageService#findOrgPage(cn.com.bizunited.cp.common.pagination.Pageable)}
     */
    @Deprecated
    List<OrgBasicInformationVo>findByBudgetFlag(String budgetFlag);

    /**
     * 根据岗位编码、组织编码，查找指定层级的组织。
     * 如果当前岗位所在组织或组织层级在查找层级之上，则往下查找指定层级组织
     * 如果当前岗位所在组织或组织层级在查找层级之下，则往上查找指定层级组织
     * @param orgType 组织层级类型 必填
     * @param positionCode 岗位编码 可输
     * @param orgCode 组织编码 可输优先组织
     * @return
     */
    List<OrgBasicInformationVo> findOrgInfosByHierarchy(OrgType orgType, String positionCode, String orgCode);

    /**
     * 根据上级节点id查询同属这一组织的组织信息
     * @param parentId
     * @return
     */
    List<OrgBasicInformationVo> findByParentId(String parentId);

    /**
     * 查询组织code下的所有子组织编码（包含自己）
     * @param orgCode
     * @return
     */
    Set<String> findAllChildOrgsByCode(String orgCode);

    /**
     * 查询组织code下的所有子组织（包含自己）
     * @param orgCode
     * @return
     */
    List<OrgBasicInformationVo> findAllChildsByCode(String orgCode);

    /**
     * 分页查询组织信息
     * @param pageable cn.com.bizunited.cp.common.pagination.Pageable#queryCondition 说明-->orgName（ 组织名称 like）、orgCode （组织编码 eq）、orgNameOrCode  （组织编码或名称 like）、budgetFlag （预算标示 eq）、parentOrgCode(父组织编码，如果存在，只查询该组织下级组织)、
     *                 orgTypes(组织层级类型{@link com.chinayanghe.msp.mdm.enums.OrgType}集合or数组 eq)、orgTypeCodes(组织层级类型编码{@link com.chinayanghe.msp.mdm.enums.OrgType#orgHierarchyCode}集合or数组 eq)、sdOrgCodes(sd组织代码集合or数组，eq)
     * @return
     */
    Page<OrgBasicInformationVo> findOrgPage(Pageable pageable);
    
    /**
     * 同步组织信息
     * @param vo
     */
    void synchronizOrgInfo(OrgBasicInformationVo vo);


    
}
